@@ -305,7 +305,7 @@ void nxagentPrintClipboardStat(char *header)
   fprintf(stderr, "  lastClientSelection             (Atom) [% 4d][%s]\n", lastClientSelection, NameForAtom(lastClientSelection));
   fprintf(stderr, "  lastClientTarget                (Atom) [% 4d][%s]\n", lastClientTarget, NameForAtom(lastClientTarget));
   fprintf(stderr, "  lastClientTime                  (Time) [%u]\n", lastServerTime);
-  fprintf(stderr, "  lastClientReqTime               (Time) [%u]\n", lastServerTime);
+  fprintf(stderr, "  lastClientReqTime               (Time) [%u]\n", lastServerReqTime);
   fprintf(stderr, "  lastClientPropertySize (unsigned long) [%lu]\n", lastClientPropertySize);
   fprintf(stderr, "  lastClientStage (ClientSelectionStage) [%d][%s]\n", lastClientStage, GetClientSelectionStageString(lastClientStage));
 
@@ -392,8 +392,6 @@ Bool nxagentValidServerTargets(Atom target)
 
 void nxagentClearClipboard(ClientPtr pClient, WindowPtr pWindow)
 {
-  int i;
-
   #ifdef DEBUG
   fprintf(stderr, "%s: Called with client [%p] window [%p].\n", __func__,
               (void *) pClient, (void *) pWindow);
@@ -405,7 +403,7 @@ void nxagentClearClipboard(ClientPtr pClient, WindowPtr pWindow)
    * Only for PRIMARY and CLIPBOARD selections.
    */
 
-  for (i = 0; i < nxagentMaxSelections; i++)
+  for (int i = 0; i < nxagentMaxSelections; i++)
   {
     if ((pClient != NULL && lastSelectionOwner[i].client == pClient) ||
             (pWindow != NULL && lastSelectionOwner[i].windowPtr == pWindow))
@@ -1241,7 +1239,9 @@ void nxagentResetSelectionOwner(void)
   {
     XSetSelectionOwner(nxagentDisplay, lastSelectionOwner[i].selection, serverWindow, CurrentTime);
 
+    #ifdef DEBUG
     fprintf(stderr, "%s: Reset clipboard state.\n", __func__);
+    #endif
 
     lastSelectionOwner[i].client = NULL;
     lastSelectionOwner[i].window = None;
@@ -1257,9 +1257,77 @@ void nxagentResetSelectionOwner(void)
   return;
 }
 
+#ifdef NXAGENT_CLIPBOARD
+void nxagentSetSelectionCallback(CallbackListPtr *callbacks, void *data,
+                                   void *args)
+{
+  /*
+   * Only act if the Trap is unset. The trap indicates that we are
+   * triggered by a clipboard event originating from the real X
+   * server. In that case we do not want to propagate back changes to
+   * the real X server, because it already knows about them and we
+   * would end up in an infinite loop of events. If there was a better
+   * way to identify that situation during Callback processing we
+   * could get rid of the Trap...
+  */
+  if (nxagentExternalClipboardEventTrap != 0)
+  {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: Trap is set, doing nothing\n", __func__);
+    #endif
+    return;
+  }
+
+  SelectionInfoRec *info = (SelectionInfoRec *)args;
+
+  Selection * pCurSel = (Selection *)info->selection;
+
+  #ifdef DEBUG
+  fprintf(stderr, "%s: pCurSel->lastTimeChanged [%d]\n", __func__, pCurSel->lastTimeChanged.milliseconds);
+  #endif
+
+  if (info->kind == SelectionSetOwner)
+  {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: called with SelectionCallbackKind SelectionSetOwner\n", __func__);
+    fprintf(stderr, "%s: pCurSel->pWin [0x%x]\n", __func__, pCurSel->pWin ? pCurSel->pWin->drawable.id : NULL);
+    fprintf(stderr, "%s: pCurSel->selection [%s]\n", __func__, NameForAtom(pCurSel->selection));
+    #endif
+
+    if ((pCurSel->pWin != NULL) &&
+        (nxagentOption(Clipboard) != ClipboardNone) &&
+        ((pCurSel->selection == XA_PRIMARY) ||
+         (pCurSel->selection == MakeAtom("CLIPBOARD", 9, 0))))
+    {
+      #ifdef DEBUG
+      fprintf(stderr, "%s: calling nxagentSetSelectionOwner\n", __func__);
+      #endif
+      nxagentSetSelectionOwner(pCurSel);
+    }
+  }
+  else if (info->kind == SelectionWindowDestroy)
+  {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: called with SelectionCallbackKind SelectionWindowDestroy\n", __func__);
+    #endif
+  }
+  else if (info->kind == SelectionClientClose)
+  {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: called with SelectionCallbackKind SelectionClientClose\n", __func__);
+    #endif
+  }
+  else
+  {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: called with unknown SelectionCallbackKind\n", __func__);
+    #endif
+  }
+}
+#endif
+
 void nxagentSetSelectionOwner(Selection *pSelection)
 {
-  int i;
   #ifdef DEBUG
   fprintf(stderr, "%s: Got called.\n", __func__);
   #endif
@@ -1270,7 +1338,7 @@ void nxagentSetSelectionOwner(Selection *pSelection)
   }
 
   #ifdef DEBUG
-  fprintf(stderr, "%s: Setting selection owner to window [0x%x].\n", __func__,
+  fprintf(stderr, "%s: Setting selection owner to serverwindow ([0x%x]).\n", __func__,
               serverWindow);
   #endif
 
@@ -1286,10 +1354,24 @@ void nxagentSetSelectionOwner(Selection *pSelection)
    * Only for PRIMARY and CLIPBOARD selections.
    */
 
-  for (i = 0; i < nxagentMaxSelections; i++)
+  for (int i = 0; i < nxagentMaxSelections; i++)
   {
     if (pSelection->selection == CurrentSelections[i].selection)
     {
+      #ifdef DEBUG
+      fprintf(stderr, "%s: lastSelectionOwner.client [0x%x] -> [0x%x]\n", __func__, lastSelectionOwner[i].client, pSelection->client);
+      fprintf(stderr, "%s: lastSelectionOwner.window [0x%x] -> [0x%x]\n", __func__, lastSelectionOwner[i].window, pSelection->window);
+      fprintf(stderr, "%s: lastSelectionOwner.windowPtr [0x%x] -> [0x%x] [0x%x] (serverWindow: [0x%x])\n", __func__, lastSelectionOwner[i].windowPtr, pSelection->pWin, nxagentWindow(pSelection->pWin), serverWindow);
+      fprintf(stderr, "%s: lastSelectionOwner.lastTimeChanged [%d]\n", __func__, lastSelectionOwner[i].lastTimeChanged);
+      #endif
+
+      /*
+       * inform the real X server that our serverWindow is the
+       * clipboard owner. The real owner window (inside nxagent) is
+       * stored in lastSelectionOwner.window.
+       * lastSelectionOwner.windowPtr points to the struct that
+       * contains all information about the owner window
+       */
       XSetSelectionOwner(nxagentDisplay, lastSelectionOwner[i].selection, serverWindow, CurrentTime);
 
       lastSelectionOwner[i].client = pSelection->client;
