@@ -71,30 +71,22 @@ is" without express or implied warranty.
 #undef  TEST
 #undef  DEBUG
 
-#define NXAGENT_DEFAULT_FONT_DIR      "/usr/share/nx/fonts"
-#define NXAGENT_ALTERNATE_FONT_DIR    "/usr/share/X11/fonts"
-#define NXAGENT_ALTERNATE_FONT_DIR_2  "/usr/share/fonts/X11"
-#define NXAGENT_ALTERNATE_FONT_DIR_3  "/usr/X11R6/lib/X11/fonts"
+const char * nxagentFontDirs[] = {
+  SYSTEMFONTDIR,
+  "/usr/share/nx/fonts",
+  "/usr/share/X11/fonts",
+  "/usr/share/fonts/X11",
+  "/usr/X11R6/lib/X11/fonts",
+  NULL
+};
 
-#define NXAGENT_DEFAULT_FONT_PATH  \
-"/usr/share/nx/fonts/misc/,/usr/share/nx/fonts/Speedo/,\
-/usr/share/nx/fonts/Type1/,/usr/share/nx/fonts/75dpi/,\
-/usr/share/nx/fonts/100dpi/,/usr/share/nx/fonts/TTF/"
-
-#define NXAGENT_ALTERNATE_FONT_PATH  \
-"/usr/share/X11/fonts/misc/,/usr/share/X11/fonts/Speedo/,\
-/usr/share/X11/fonts/Type1/,/usr/share/X11/fonts/75dpi/,\
-/usr/share/X11/fonts/100dpi/,/usr/share/X11/fonts/TTF/"
-
-#define NXAGENT_ALTERNATE_FONT_PATH_2  \
-"/usr/share/fonts/X11/misc/,/usr/share/fonts/X11/Speedo/,\
-/usr/share/fonts/X11/Type1/,/usr/share/fonts/X11/75dpi/,\
-/usr/share/fonts/X11/100dpi/,/usr/share/fonts/X11/TTF/"
-
-#define NXAGENT_ALTERNATE_FONT_PATH_3  \
-"/usr/X11R6/lib/X11/fonts/misc/,/usr/X11R6/lib/X11/fonts/Speedo/,\
-/usr/X11R6/lib/X11/fonts/Type1/,/usr/X11R6/lib/X11/fonts/75dpi/,\
-/usr/X11R6/lib/X11/fonts/100dpi/,/usr/X11R6/lib/X11/fonts/TTF/"
+const char * nxagentFontSubdirs[] = {
+  "Type1",
+  "75dpi",
+  "100dpi",
+  "TTF",
+  NULL
+};
 
 #undef NXAGENT_FONTCACHE_DEBUG
 #undef NXAGENT_RECONNECT_FONT_DEBUG
@@ -173,8 +165,6 @@ static struct _nxagentFailedToReconnectFonts
 
 void nxagentFreeFontCache(void)
 {
-  int i;
-
   #ifdef NXAGENT_FONTCACHE_DEBUG
   fprintf(stderr, "Font: Freeing nxagent font cache\n");
   #endif
@@ -186,7 +176,7 @@ void nxagentFreeFontCache(void)
   fprintf(stderr, "Font: Freeing nxagent font cache, there are [%d] entries.\n", CACHE_INDEX);
   #endif
 
-  for (i = 0; i < CACHE_INDEX; i++)
+  for (int i = 0; i < CACHE_INDEX; i++)
   {
     #ifdef NXAGENT_FONTCACHE_DEBUG
     fprintf(stderr, "Font: Freeing nxagent font cache entry [%d] entry pointer is [%p], name [%s]\n",
@@ -216,8 +206,6 @@ void nxagentFreeFontCache(void)
 
 void nxagentListRemoteFonts(const char *searchPattern, const int maxNames)
 {
-  int i, q, p;
-
   char **xList;
   int  xLen = 0;
 
@@ -249,7 +237,7 @@ void nxagentListRemoteFonts(const char *searchPattern, const int maxNames)
    * other one will select the 'real' fonts.
    */
 
-  for (p = 0; p < patternsQt; p++)
+  for (int p = 0; p < patternsQt; p++)
   {
     xList = XListFonts(nxagentDisplay, patterns[p], maxNames, &xLen);
 
@@ -264,11 +252,9 @@ void nxagentListRemoteFonts(const char *searchPattern, const int maxNames)
 
     nxagentListRemoteAddName(searchPattern, maxNames);
 
-    for (i = 0; i < xLen; i++)
+    for (int i = 0; i < xLen; i++)
     {
-      q = 1;
-
-      nxagentListRemoteAddName(xList[i], q);
+      nxagentListRemoteAddName(xList[i], 1);
     }
 
     XFreeFontNames(xList);
@@ -278,7 +264,7 @@ void nxagentListRemoteFonts(const char *searchPattern, const int maxNames)
 
   fprintf(stderr, "nxagentListRemoteFonts: Printing remote font list.\n");
 
-  for (i = 0; i < nxagentRemoteFontList.length; i++)
+  for (int i = 0; i < nxagentRemoteFontList.length; i++)
   {
     fprintf(stderr, "Font# %d, \"%s\"\n", i, nxagentRemoteFontList.list[i]->name);
   }
@@ -361,9 +347,7 @@ void nxagentListRemoteAddName(const char *name, int status)
 
 static void nxagentFreeRemoteFontList(nxagentFontList *listRec)
 {
-  int l;
-
-  for (l = 0; l < listRec -> length; l++)
+  for (int l = 0; l < listRec -> length; l++)
   {
     if (listRec -> list[l])
     {
@@ -385,18 +369,16 @@ static void nxagentFreeRemoteFontList(nxagentFontList *listRec)
 
 Bool nxagentFontFind(const char *name, int *pos)
 {
- int low,high,res,iter,lpos;
-
  if (!nxagentRemoteFontList.length)
  {
     *pos=0;
     return False;
  }
- low = 0;
- high = nxagentRemoteFontList.length - 1;
- iter = 0;
- res = 1;
- lpos = nxagentRemoteFontList.length;
+ int low = 0;
+ int high = nxagentRemoteFontList.length - 1;
+ int iter = 0;
+ int res = 1;
+ int lpos = nxagentRemoteFontList.length;
  while (low <= high)
  {
    *pos = (high + low)/2;
@@ -432,18 +414,15 @@ Bool nxagentFontFind(const char *name, int *pos)
 Bool nxagentFontLookUp(const char *name)
 {
   int i;
-  int result;
-
-  char *scalable;
 
   if (name != NULL && strlen(name) == 0)
   {
     return 0;
   }
 
-  result = nxagentFontFind(name, &i);
+  int result = nxagentFontFind(name, &i);
 
-  scalable = NULL;
+  char *scalable = NULL;
 
   /*
    * Let's try with the scalable font description.
@@ -451,9 +430,7 @@ Bool nxagentFontLookUp(const char *name)
 
   if (result == 0)
   {
-    scalable = nxagentMakeScalableFontName(name, 0); 
-
-    if (scalable != NULL)
+    if ((scalable = nxagentMakeScalableFontName(name, 0)) != NULL)
     {
       result = nxagentFontFind(scalable, &i);
 
@@ -467,9 +444,7 @@ Bool nxagentFontLookUp(const char *name)
 
   if (result == 0)
   {
-    scalable = nxagentMakeScalableFontName(name, 1); 
-
-    if (scalable != NULL)
+    if ((scalable = nxagentMakeScalableFontName(name, 1)) != NULL)
     {
       result = nxagentFontFind(scalable, &i);
 
@@ -711,7 +686,7 @@ Bool nxagentUnrealizeFont(ScreenPtr pScreen, FontPtr pFont)
 int nxagentDestroyNewFontResourceType(void * p, XID id)
 {
   #ifdef TEST
-  fprintf(stderr, "nxagentDestroyNewFontResourceType: Destroying mirror id [%ld] for font at [%p].\n",
+  fprintf(stderr, "%s: Destroying mirror id [%ld] for font at [%p].\n", __func__,
               nxagentFontPriv((FontPtr) p) -> mirrorID, (void *) p);
   #endif
 
@@ -865,7 +840,6 @@ static void nxagentFontDisconnect(FontPtr pFont, XID param1, void * param2)
 {
   nxagentPrivFont *privFont;
   Bool *pBool = (Bool*)param2;
-  int i;
 
   if (pFont == NULL || !*pBool)
     return;
@@ -877,7 +851,7 @@ static void nxagentFontDisconnect(FontPtr pFont, XID param1, void * param2)
               (void *) pFont, privFont -> font_struct ? nxagentFont(pFont) : 0);
   #endif
 
-  for (i = 0; i < CACHE_INDEX; i++)
+  for (int i = 0; i < CACHE_INDEX; i++)
   {
     if (strcasecmp(CACHE_NAME(i), privFont -> fontName) == 0)
     {
@@ -905,7 +879,6 @@ static void nxagentFontDisconnect(FontPtr pFont, XID param1, void * param2)
 
 static void nxagentCollectFailedFont(FontPtr fpt, XID id)
 {
-
   if (nxagentFailedToReconnectFonts.font == NULL)
   {
     nxagentFailedToReconnectFonts.size = 8;
@@ -1051,13 +1024,11 @@ static void nxagentFontReconnect(FontPtr pFont, XID param1, void * param2)
 
 static void nxagentFreeCacheBeforeReconnect(void)
 {
-  int i;
-
   #ifdef NXAGENT_RECONNECT_FONT_DEBUG
   printFontCacheDump("nxagentFreeCacheBeforeReconnect");
   #endif
 
-  for (i = 0; i < CACHE_INDEX; i++)
+  for (int i = 0; i < CACHE_INDEX; i++)
   {
     if (CACHE_FSTRUCT(i))
     {
@@ -1069,15 +1040,13 @@ static void nxagentFreeCacheBeforeReconnect(void)
 
 static void nxagentCleanCacheAfterReconnect(void)
 {
-  int i, j;
   int real_size = CACHE_INDEX;
-  nxCacheFontEntryRecPtr swapEntryPtr;
 
   #ifdef NXAGENT_RECONNECT_FONT_DEBUG
   printFontCacheDump("nxagentCleanCacheAfterReconnect");
   #endif
 
-  for (i = 0; i < CACHE_INDEX; i++)
+  for (int i = 0; i < CACHE_INDEX; i++)
   {
     if(CACHE_FSTRUCT(i) == NULL)
     {
@@ -1086,8 +1055,11 @@ static void nxagentCleanCacheAfterReconnect(void)
     }
   }
 
-  for (i = 0; i < real_size; i++)
+  for (int i = 0; i < real_size; i++)
   {
+      int j;
+      nxCacheFontEntryRecPtr swapEntryPtr;
+
       /* Find - first bad occurrence if exist. */
       while ((i < real_size) && CACHE_FSTRUCT(i)) i++;
 
@@ -1116,11 +1088,9 @@ static void nxagentCleanCacheAfterReconnect(void)
 #ifdef NXAGENT_RECONNECT_FONT_DEBUG
 static void printFontCacheDump(char* msg)
 {
-  int i;
-
   fprintf(stderr, "%s - begin -\n", msg);
 
-  for (i = 0; i < CACHE_INDEX; i++)
+  for (int i = 0; i < CACHE_INDEX; i++)
   {
     if (CACHE_FSTRUCT(i))
     {
@@ -1137,7 +1107,6 @@ static void printFontCacheDump(char* msg)
 
 Bool nxagentReconnectAllFonts(void *p0)
 {
-  int cid;
   Bool fontSuccess = True;
 
   reconnectFlexibility = *((int *) p0);
@@ -1155,7 +1124,7 @@ Bool nxagentReconnectAllFonts(void *p0)
   FindClientResourcesByType(clients[serverClient -> index], RT_NX_FONT,
                                 (FindResType) nxagentFontReconnect, &fontSuccess);
 
-  for (cid = 0; cid < MAXCLIENTS; cid++)
+  for (int cid = 0; cid < MAXCLIENTS; cid++)
   {
     if (clients[cid])
     {
@@ -1266,7 +1235,6 @@ static void nxagentFreeFailedToReconnectFonts(void)
 
 Bool nxagentReconnectFailedFonts(void *p0)
 {
-  int i;
   int attempt = 1;
   const int maxAttempt = 5;
 
@@ -1320,7 +1288,7 @@ Bool nxagentReconnectFailedFonts(void *p0)
     nxagentFreeRemoteFontList(&nxagentRemoteFontList);
     nxagentListRemoteFonts("*", nxagentMaxFontNames);
 
-    for(i = 0; i < nxagentFailedToReconnectFonts.index; i++)
+    for(int i = 0; i < nxagentFailedToReconnectFonts.index; i++)
     {
       fontSuccess = True;
 
@@ -1373,7 +1341,6 @@ Bool nxagentReconnectFailedFonts(void *p0)
 
 Bool nxagentDisconnectAllFonts(void)
 {
-  int cid;
   Bool fontSuccess = True;
 
   #if defined(NXAGENT_RECONNECT_DEBUG) || defined(NXAGENT_RECONNECT_FONT_DEBUG)
@@ -1392,7 +1359,7 @@ Bool nxagentDisconnectAllFonts(void)
   FindClientResourcesByType(clients[serverClient -> index], RT_NX_FONT,
                                 (FindResType) nxagentFontDisconnect, &fontSuccess);
 
-  for(cid = 0; cid < MAXCLIENTS; cid++)
+  for(int cid = 0; cid < MAXCLIENTS; cid++)
   {
     if( clients[cid] && fontSuccess )
     {
@@ -1418,14 +1385,14 @@ static Bool nxagentGetFontServerPath(char * fontServerPath, int size)
       snprintf(fontServerPath, min(size, len + 1), "%s", path + 1);
 
       #ifdef TEST
-      fprintf(stderr, "nxagentGetFontServerPath: Got path [%s].\n",
+      fprintf(stderr, "%s: Got path [%s].\n", __func__,
                   fontServerPath);
       #endif
     }
     else
     {
       #ifdef TEST
-      fprintf(stderr, "nxagentGetFontServerPath: WARNING! Font server tunneling not enabled.\n");
+      fprintf(stderr, "%s: WARNING! Font server tunneling not enabled.\n", __func__);
       #endif
 
       return False;
@@ -1434,7 +1401,7 @@ static Bool nxagentGetFontServerPath(char * fontServerPath, int size)
   else
   {
     #ifdef TEST
-    fprintf(stderr, "nxagentGetFontServerPath: WARNING! Failed to get path for font server tunneling.\n");
+    fprintf(stderr, "%s: WARNING! Failed to get path for font server tunneling.\n", __func__);
     #endif
 
     return False;
@@ -1443,13 +1410,50 @@ static Bool nxagentGetFontServerPath(char * fontServerPath, int size)
   return True;
 }
 
+void nxagentVerifySingleFontPath(char **dest, const char *fontDir)
+{
+  if (!dest || !*dest)
+    return;
+
+  #ifdef TEST
+  fprintf(stderr, "%s: Assuming fonts in directory [%s].\n", __func__,
+	  validateString(fontDir));
+  #endif
+
+  for (int i = 0; ; i++)
+  {
+    char *tmppath = NULL;
+    int rc;
+
+    const char *subdir = nxagentFontSubdirs[i];
+
+    if (subdir == NULL)
+      return;
+
+    if (**dest != '\0')
+    {
+      rc = asprintf(&tmppath, "%s,%s/%s", *dest, fontDir, subdir);
+    }
+    else
+    {
+      rc = asprintf(&tmppath, "%s/%s", fontDir, subdir);
+    }
+
+    if (rc == -1)
+      return;
+
+    free(*dest);
+    *dest = tmppath;
+    tmppath = NULL;
+  }
+}
+
 void nxagentVerifyDefaultFontPath(void)
 {
-  struct stat dirStat;
   static char *fontPath;
 
   #ifdef TEST
-  fprintf(stderr, "nxagentVerifyDefaultFontPath: Going to search for one or more valid font paths.\n");
+  fprintf(stderr, "%s: Going to search for one or more valid font paths.\n", __func__);
   #endif
 
   /*
@@ -1459,128 +1463,65 @@ void nxagentVerifyDefaultFontPath(void)
   if ((fontPath = strdup(defaultFontPath)) == NULL)
   {
     #ifdef WARNING
-    fprintf(stderr, "nxagentVerifyDefaultFontPath: WARNING! Unable to allocate memory for a new font path. "
-                "Using the default font path [%s].\n", validateString(defaultFontPath));
+    fprintf(stderr, "%s: WARNING! Unable to allocate memory for a new font path. "
+            "Using the default font path [%s].\n", __func__,
+            validateString(defaultFontPath));
     #endif
 
     return;
   }
 
-  if (stat(NXAGENT_DEFAULT_FONT_DIR, &dirStat) == 0 &&
-          S_ISDIR(dirStat.st_mode) != 0)
+  for (int i = 0; ; i++)
   {
-    /*
-     * Let's use the old "/usr/share/nx/fonts" style.
-     */
+    int j;
+    const char *dir = nxagentFontDirs[i];
 
-    #ifdef TEST
-    fprintf(stderr, "nxagentVerifyDefaultFontPath: Assuming fonts in directory [%s].\n",
-                validateString(NXAGENT_DEFAULT_FONT_DIR));
-    #endif
-
-    if (*fontPath != '\0')
+    if (dir == NULL)
     {
-      fontPath = realloc(fontPath, strlen(fontPath) + strlen(NXAGENT_DEFAULT_FONT_PATH) + 2);
-      strcat(fontPath, ",");
+      break;
     }
     else
     {
-      fontPath = realloc(fontPath, strlen(fontPath) + strlen(NXAGENT_DEFAULT_FONT_PATH) + 1);
-    }
+      for (j = 0; j <= i; j++)
+      {
+        //if (strcmp(nxagentFontDirs[j], dir) == 0)
+        if (nxagentFontDirs[j] == dir)
+        {
+          break;
+        }
+      }
 
-    strcat(fontPath, NXAGENT_DEFAULT_FONT_PATH);
+      if (j == i)
+      {
+        nxagentVerifySingleFontPath(&fontPath, dir);
+      }
+#ifdef TEST
+      else
+      {
+        fprintf(stderr, "%s: Skipping duplicate font dir [%s].\n", __func__,
+                validateString(dir));
+      }
+#endif
+    }
   }
 
-  if (stat(NXAGENT_ALTERNATE_FONT_DIR, &dirStat) == 0 &&
-          S_ISDIR(dirStat.st_mode) != 0)
-  {
-    /*
-     * Let's use the new "/usr/share/X11/fonts" path.
-     */
-
-    #ifdef TEST
-    fprintf(stderr, "nxagentVerifyDefaultFontPath: Assuming fonts in directory [%s].\n",
-                validateString(NXAGENT_ALTERNATE_FONT_DIR));
-    #endif
-
-    if (*fontPath != '\0')
-    {
-      fontPath = realloc(fontPath, strlen(fontPath) + strlen(NXAGENT_ALTERNATE_FONT_PATH) + 2);
-      strcat(fontPath, ",");
-    }
-    else
-    {
-      fontPath = realloc(fontPath, strlen(fontPath) + strlen(NXAGENT_ALTERNATE_FONT_PATH) + 1);
-    }
-
-    strcat(fontPath, NXAGENT_ALTERNATE_FONT_PATH);
-  }
-
-  if (stat(NXAGENT_ALTERNATE_FONT_DIR_2, &dirStat) == 0 &&
-          S_ISDIR(dirStat.st_mode) != 0)
-  {
-    /*
-     * Let's use the "/usr/share/fonts/X11" path.
-     */
-
-    #ifdef TEST
-    fprintf(stderr, "nxagentVerifyDefaultFontPath: Assuming fonts in directory [%s].\n",
-                validateString(NXAGENT_ALTERNATE_FONT_DIR_2));
-    #endif
-
-    if (*fontPath != '\0')
-    {
-      fontPath = realloc(fontPath, strlen(fontPath) + strlen(NXAGENT_ALTERNATE_FONT_PATH_2) + 2);
-      strcat(fontPath, ",");
-    }
-    else
-    {
-      fontPath = realloc(fontPath, strlen(fontPath) + strlen(NXAGENT_ALTERNATE_FONT_PATH_2) + 1);
-    }
-
-    strcat(fontPath, NXAGENT_ALTERNATE_FONT_PATH_2);
-  }
-
-  if (stat(NXAGENT_ALTERNATE_FONT_DIR_3, &dirStat) == 0 &&
-          S_ISDIR(dirStat.st_mode) != 0)
-  {
-    /*
-     * Let's use the "/usr/X11R6/lib/X11/fonts" path.
-     */
-
-    #ifdef TEST
-    fprintf(stderr, "nxagentVerifyDefaultFontPath: Assuming fonts in directory [%s].\n",
-                validateString(NXAGENT_ALTERNATE_FONT_DIR_3));
-    #endif
-
-    if (*fontPath != '\0')
-    {
-      fontPath = realloc(fontPath, strlen(fontPath) + strlen(NXAGENT_ALTERNATE_FONT_PATH_3) + 2);
-      strcat(fontPath, ",");
-    }
-    else
-    {
-      fontPath = realloc(fontPath, strlen(fontPath) + strlen(NXAGENT_ALTERNATE_FONT_PATH_3) + 1);
-    }
-
-    strcat(fontPath, NXAGENT_ALTERNATE_FONT_PATH_3);
-  }
-  if (*fontPath == '\0') 
+  if (*fontPath == '\0')
   {
     #ifdef WARNING
-    fprintf(stderr, "nxagentVerifyDefaultFontPath: WARNING! Can't find a valid font directory.\n");
-
-    fprintf(stderr, "nxagentVerifyDefaultFontPath: WARNING! Using font path [%s].\n",
-                validateString(defaultFontPath));
+    fprintf(stderr, "%s: WARNING! Can't find a valid font directory.\n", __func__);
+    fprintf(stderr, "%s: WARNING! Using font path [%s].\n", __func__,
+            validateString(defaultFontPath));
     #endif
   }
   else
   {
+    /* do _not_ free defaultFontPath here - it's either set at compile time or
+       part of argv */
     defaultFontPath = fontPath;
- 
+
     #ifdef TEST
-    fprintf(stderr, "nxagentVerifyDefaultFontPath: Using font path [%s].\n",
-                validateString(defaultFontPath));
+    fprintf(stderr, "%s: Using font path [%s].\n", __func__,
+            validateString(defaultFontPath));
     #endif
  }
 
@@ -1681,7 +1622,6 @@ XFontStruct* nxagentLoadQueryFont(register Display *dpy, char *name, FontPtr pFo
 
 int nxagentFreeFont(XFontStruct *fs)
 {
-
   if (fs -> per_char)
   {
     #ifdef USE_XF86BIGFONT
