@@ -553,10 +553,11 @@ void nxagentChangeKeyboardControl(DeviceIntPtr pDev, KeybdCtrl *ctrl)
 
     value_mask = KBLed | KBLedMode;
 
-    for (int i = 1; i <= 32; i++)
+    for (int i = 1; i <= XkbNumIndicators; i++)
     {
+      unsigned int mask = (unsigned int)1 << (i - 1);
       values.led = i;
-      values.led_mode = (ctrl->leds & (1 << (i - 1))) ? LedModeOn : LedModeOff;
+      values.led_mode = (ctrl->leds & mask) ? LedModeOn : LedModeOff;
 
       XChangeKeyboardControl(nxagentDisplay, value_mask, &values);
     }
@@ -647,14 +648,15 @@ N/A
         if (keymap64 == NULL)
         {
           XFreeModifiermap(modifier_keymap);
-
           return -1;
         }
 
         len = (max_keycode - min_keycode + 1) * mapWidth;
         keymap = (KeySym *)malloc(len * sizeof(KeySym));
         for(i = 0; i < len; ++i)
+        {
           keymap[i] = keymap64[i];
+        }
         XFree(keymap64);
       }
 
@@ -668,7 +670,6 @@ N/A
       if (keymap == NULL)
       {
         XFreeModifiermap(modifier_keymap);
-
         return -1;
       }
 
@@ -682,18 +683,24 @@ N/A
 
       memset(modmap, 0, sizeof(modmap));
       for (j = 0; j < 8; j++)
-        for(i = 0; i < modifier_keymap->max_keypermod; i++) {
+      {
+        for(i = 0; i < modifier_keymap->max_keypermod; i++)
+        {
           CARD8 keycode;
           if ((keycode =
               modifier_keymap->
                 modifiermap[j * modifier_keymap->max_keypermod + i]))
+          {
             modmap[keycode] |= 1<<j;
+          }
 
           if (keycode > 0)
           {
             nxagentCheckModifierMasks(keycode, j);
           }
         }
+      }
+
       XFreeModifiermap(modifier_keymap);
       modifier_keymap = NULL;
 
@@ -747,13 +754,10 @@ XkbError:
 
         #ifdef TEST
         fprintf(stderr, "nxagentKeyboardProc: Using XKB extension.\n");
-        #endif
-
-        #ifdef TEST
         fprintf(stderr, "nxagentKeyboardProc: nxagentKeyboard is [%s].\n", nxagentKeyboard ? nxagentKeyboard : "NULL");
         #endif
 
-        if (nxagentX2go == 1 && nxagentKeyboard && (strcmp(nxagentKeyboard, "null/null") == 0))
+        if (nxagentX2go && nxagentKeyboard && (strcmp(nxagentKeyboard, "null/null") == 0))
         {
           #ifdef TEST
           fprintf(stderr, "%s: changing nxagentKeyboard from [null/null] to [clone].\n", __func__);
@@ -779,10 +783,9 @@ XkbError:
         {
           for (i = 0; nxagentKeyboard[i] != '/' && nxagentKeyboard[i] != 0; i++);
 
-          if(nxagentKeyboard[i] == 0 || nxagentKeyboard[i + 1] == 0 || i == 0)
+          if (nxagentKeyboard[i] == 0 || nxagentKeyboard[i + 1] == 0 || i == 0)
           {
             ErrorF("Warning: Wrong keyboard type: %s.\n", nxagentKeyboard);
-
             goto XkbError;
           }
 
@@ -842,7 +845,7 @@ XkbError:
         {
           #ifdef TEST
           fprintf(stderr, "nxagentKeyboardProc: Using default keyboard: model [%s] layout [%s].\n",
-                      model, layout);
+                      model?model:"(default)", layout?layout:"(default)");
           #endif
         }
 
@@ -872,8 +875,10 @@ XkbError:
              * method for switching that off is the creation of a dir
              * instead of a file.
              */
-            if (nxagentX2go == 1)
+            if (nxagentX2go)
+            {
               nxagentWriteKeyboardDir();
+            }
           }
           else
           {
@@ -890,8 +895,10 @@ XkbError:
              * know about that yet. Once x2go starts using clone
              * we can drop this here.
              */
-            if (nxagentX2go == 1)
+            if (nxagentX2go)
+            {
               nxagentWriteKeyboardFile(nxagentRemoteRules, nxagentRemoteModel, nxagentRemoteLayout, nxagentRemoteVariant, nxagentRemoteOptions);
+            }
           }
         }
         #ifdef DEBUG
@@ -905,19 +912,20 @@ XkbError:
 
         if (xkb && xkb->geom)
         {
-            XkbGetControls(nxagentDisplay, XkbAllControlsMask, xkb);
+          XkbGetControls(nxagentDisplay, XkbAllControlsMask, xkb);
         }
 #ifdef TEST
         else
         {
-            fprintf(stderr, "nxagentKeyboardProc: No current keyboard.\n");
+          fprintf(stderr, "nxagentKeyboardProc: No current keyboard.\n");
         }
 #endif
 
         #ifdef DEBUG
         fprintf(stderr, "nxagentKeyboardProc: Going to set rules and init device: "
                         "[rules='%s',model='%s',layout='%s',variant='%s',options='%s'].\n",
-                        rules, model, layout, variant, options);
+                        rules?rules:"(default)", model?model:"(default)", layout?layout:"(default)",
+                        variant?variant:"(default)", options?options:"(default)");
         #endif
 
         XkbSetRulesDflts(rules, model, layout, variant, options);
@@ -931,19 +939,23 @@ XkbError:
 
         if (xkb && xkb->geom)
         {
-            XkbDDXChangeControls(pDev, xkb->ctrls, xkb->ctrls);
+          XkbDDXChangeControls(pDev, xkb->ctrls, xkb->ctrls);
         }
 
         if (nxagentOption(Shadow) == 1 && pDev && pDev->key)
         {
           NXShadowInitKeymap(&(pDev->key->curKeySyms));
         }
+
+	free(rules);
+	free(variant);
+	free(options);
       }
 
       if (xkb)
       {
-          XkbFreeKeyboard(xkb, XkbAllComponentsMask, True);
-          xkb = NULL;
+        XkbFreeKeyboard(xkb, XkbAllComponentsMask, True);
+        xkb = NULL;
       }
 
       free(model);
@@ -1018,7 +1030,6 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
       break;
 
     case DEVICE_CLOSE:
-
       #ifdef TEST
       fprintf(stderr, "nxagentKeyboardProc: Called for [DEVICE_CLOSE].\n");
       #endif
@@ -1285,8 +1296,6 @@ static int nxagentRestoreKeyboardDeviceData(DeviceIntPtr devBackup, DeviceIntPtr
 
 static int nxagentFreeKeyboardDeviceData(DeviceIntPtr dev)
 {
-  KbdFeedbackPtr k, knext;
-
   if (!dev)
   {
     #ifdef PANIC
@@ -1320,14 +1329,18 @@ static int nxagentFreeKeyboardDeviceData(DeviceIntPtr dev)
       dev->focus = NULL;
   }
 
-  for (k = dev->kbdfeed; k; k = knext)
+  if (dev->kbdfeed)
   {
-      knext = k->next;
-      #ifdef XKB
-      if (k->xkb_sli)
-          XkbFreeSrvLedInfo(k->xkb_sli);
-      #endif
-      free(k);
+      for (KbdFeedbackPtr k = dev->kbdfeed, knext; k; k = knext)
+      {
+          knext = k->next;
+          #ifdef XKB
+          if (k->xkb_sli)
+              XkbFreeSrvLedInfo(k->xkb_sli);
+          #endif
+          free(k);
+      }
+      dev->kbdfeed = NULL;
   }
 
   #ifdef DEBUG
@@ -1676,7 +1689,10 @@ static char* getKeyboardFilePath(void)
       free(sessionpath);
       FatalError("malloc for keyboard file path failed.");
     }
-    free(sessionpath);
+    else
+    {
+      free(sessionpath);
+    }
   }
   else
   {
