@@ -44,7 +44,6 @@
 #include <libxml/tree.h>
 
 extern Bool nxagentWMIsRunning;
-extern Bool nxagentIpaq;
 extern char *nxagentKeystrokeFile;
 
 #ifdef NX_DEBUG_INPUT
@@ -113,8 +112,6 @@ struct nxagentSpecialKeystrokeMap default_map[] = {
   {KEYSTROKE_FULLSCREEN, ControlMask | ShiftMask, True, XK_f},
   {KEYSTROKE_MINIMIZE, ControlMask, True, XK_m},
   {KEYSTROKE_DEFER, ControlMask, True, XK_e},
-  {KEYSTROKE_IGNORE, ControlMask, True, XK_BackSpace},
-  {KEYSTROKE_IGNORE, 0, False, XK_Terminate_Server},
   {KEYSTROKE_FORCE_SYNCHRONIZATION, ControlMask, True, XK_j},
 #ifdef DUMP
   {KEYSTROKE_REGIONS_ON_SCREEN, ControlMask, True, XK_a},
@@ -509,13 +506,6 @@ Bool nxagentCheckSpecialKeystroke(XKeyEvent *X, enum HandleEventResult *result)
    *        here.
    */
 
-  if (X -> keycode == 130 && nxagentIpaq)
-  {
-    *result = doStartKbd;
-
-    return True;
-  }
-
   switch (stroke) {
 #ifdef DEBUG_TREE
     case KEYSTROKE_DEBUG_TREE:
