@@ -278,9 +278,9 @@ Dispatch(void)
     if (!clientReady)
 	return;
 
-  #ifdef WATCH
+    #ifdef WATCH
 
-  fprintf(stderr, "Dispatch: Watchpoint 12.\n");
+    fprintf(stderr, "Dispatch: Watchpoint 12.\n");
 
 /*
 Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
@@ -294,22 +294,22 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 #98     1		256 bits (0 KB) ->	34 bits (0 KB) ->	256/1 -> 34/1	= 7.529:1
 */
 
-  sleep(30);
+    sleep(30);
 
-  #endif
+    #endif
 
-  #ifdef TEST
-  fprintf(stderr, "Dispatch: Value of dispatchException is [%x].\n",
-              dispatchException);
+    #ifdef TEST
+    fprintf(stderr, "Dispatch: Value of dispatchException is [%x].\n",
+                dispatchException);
 
-  fprintf(stderr, "Dispatch: Value of dispatchExceptionAtReset is [%x].\n",
-              dispatchExceptionAtReset);
-  #endif
+    fprintf(stderr, "Dispatch: Value of dispatchExceptionAtReset is [%x].\n",
+                dispatchExceptionAtReset);
+    #endif
 
-  if (!(dispatchException & DE_TERMINATE))
-    dispatchException = 0;
+    if (!(dispatchException & DE_TERMINATE))
+        dispatchException = 0;
 
-  while (!dispatchException)
+    while (!dispatchException)
     {
         if (*icheck[0] != *icheck[1])
 	{
@@ -468,12 +468,6 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 #endif
 
 		client->sequence++;
-#ifdef DEBUG
-		if ((client->requestLogIndex >= MAX_REQUEST_LOG) || (client->requestLogIndex <= 0))
-		    client->requestLogIndex = 0;
-		client->requestLog[client->requestLogIndex] = MAJOROP;
-		client->requestLogIndex++;
-#endif
 		if (result > (maxBigRequestSize << 2))
 		    result = BadLength;
 		else
@@ -626,7 +620,7 @@ ProcReparentWindow(register ClientPtr client)
 int
 ProcQueryTree(register ClientPtr client)
 {
-    xQueryTreeReply reply;
+    xQueryTreeReply reply = {0};
     int numChildren = 0;
     register WindowPtr pChild, pWin, pHead;
     Window  *childIDs = (Window *)NULL;
@@ -637,7 +631,6 @@ ProcQueryTree(register ClientPtr client)
 					   DixReadAccess);
     if (!pWin)
         return(BadWindow);
-    memset(&reply, 0, sizeof(xQueryTreeReply));
     reply.type = X_Reply;
     reply.root = pWin->drawable.pScreen->root->drawable.id;
     reply.sequenceNumber = client->sequence;
@@ -684,113 +677,6 @@ ProcQueryTree(register ClientPtr client)
 }
 
 
-int
-ProcSetSelectionOwner(register ClientPtr client)
-{
-    WindowPtr pWin;
-    TimeStamp time;
-    REQUEST(xSetSelectionOwnerReq);
-
-    REQUEST_SIZE_MATCH(xSetSelectionOwnerReq);
-    UpdateCurrentTime();
-    time = ClientTimeToServerTime(stuff->time);
-
-    /* If the client's time stamp is in the future relative to the server's
-	time stamp, do not set the selection, just return success. */
-    if (CompareTimeStamps(time, currentTime) == LATER)
-    	return Success;
-    if (stuff->window != None)
-    {
-        pWin = (WindowPtr)SecurityLookupWindow(stuff->window, client,
-					       DixReadAccess);
-        if (!pWin)
-            return(BadWindow);
-    }
-    else
-        pWin = (WindowPtr)None;
-    if (ValidAtom(stuff->selection))
-    {
-	int i = 0;
-
-	/*
-	 * First, see if the selection is already set... 
-	 */
-	while ((i < NumCurrentSelections) && 
-	       CurrentSelections[i].selection != stuff->selection) 
-            i++;
-        if (i < NumCurrentSelections)
-        {        
-	    xEvent event = {0};
-
-	    /* If the timestamp in client's request is in the past relative
-		to the time stamp indicating the last time the owner of the
-		selection was set, do not set the selection, just return 
-		success. */
-            if (CompareTimeStamps(time, CurrentSelections[i].lastTimeChanged)
-		== EARLIER)
-		return Success;
-	    if (CurrentSelections[i].client &&
-		(!pWin || (CurrentSelections[i].client != client)))
-	    {
-		event.u.u.type = SelectionClear;
-		event.u.selectionClear.time = time.milliseconds;
-		event.u.selectionClear.window = CurrentSelections[i].window;
-		event.u.selectionClear.atom = CurrentSelections[i].selection;
-		(void) TryClientEvents (CurrentSelections[i].client, &event, 1,
-				NoEventMask, NoEventMask /* CantBeFiltered */,
-				NullGrab);
-	    }
-	}
-	else
-	{
-	    /*
-	     * It doesn't exist, so add it...
-	     */
-	    Selection *newsels;
-
-	    if (i == 0)
-		newsels = (Selection *)malloc(sizeof(Selection));
-	    else
-		newsels = (Selection *)realloc(CurrentSelections,
-			    (NumCurrentSelections + 1) * sizeof(Selection));
-	    if (!newsels)
-		return BadAlloc;
-	    NumCurrentSelections++;
-	    CurrentSelections = newsels;
-	    CurrentSelections[i].selection = stuff->selection;
-	}
-        CurrentSelections[i].lastTimeChanged = time;
-	CurrentSelections[i].window = stuff->window;
-	CurrentSelections[i].pWin = pWin;
-	CurrentSelections[i].client = (pWin ? client : NullClient);
-	if (SelectionCallback)
-	{
-	    SelectionInfoRec	info;
-
-	    info.selection = &CurrentSelections[i];
-	    info.kind= SelectionSetOwner;
-	    CallCallbacks(&SelectionCallback, &info);
-	}
-
-#ifdef NXAGENT_CLIPBOARD
-      if ((CurrentSelections[i].pWin != NULL) &&
-              (nxagentOption(Clipboard) != ClipboardNone) &&
-                  ((CurrentSelections[i].selection == XA_PRIMARY) ||
-                       (CurrentSelections[i].selection == MakeAtom("CLIPBOARD", 9, 0))))
-      {
-        nxagentSetSelectionOwner(&CurrentSelections[i]);
-      }
-#endif
-	return (client->noClientException);
-    }
-    else 
-    {
-	client->errorValue = stuff->selection;
-        return (BadAtom);
-    }
-}
-
-
 int
 ProcConvertSelection(register ClientPtr client)
 {
@@ -1309,6 +1195,9 @@ CloseDownClient(register ClientPtr client)
 	    CallCallbacks((&ClientStateCallback), (void *)&clientinfo);
 	} 	    
 	FreeClientResources(client);
+	/* Disable client ID tracking. This must be done after
+	 * ClientStateCallback. */
+	ReleaseClientIds(client);
 	if (client->index < nextFreeClientID)
 	    nextFreeClientID = client->index;
 	clients[client->index] = NullClient;
