@@ -296,7 +296,7 @@ InitRootWindow(WindowPtr pWin)
     #ifdef NXAGENT_ARTSD
     {
       char artsd_port[10];
-      int nPort;
+      short int nPort;
       extern void nxagentPropagateArtsdProperties(ScreenPtr pScreen, char *port);
       nPort = atoi(display) + 7000;
       sprintf(artsd_port,"%d", nPort);
@@ -1021,8 +1021,6 @@ SaveScreens(int on, int mode)
 
     if (on == SCREEN_SAVER_FORCER)
     {
-	UpdateCurrentTimeIf();
-	lastDeviceEventTime = currentTime;
 	if (mode == ScreenSaverReset)
 	    what = SCREEN_SAVER_OFF;
 	else
